package cn.com.infosec.asn1.x509.sigi;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERPrintableString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x500.DirectoryString;
import java.math.BigInteger;
import java.util.Enumeration;

public class PersonalData extends ASN1Encodable {
   private NameOrPseudonym nameOrPseudonym;
   private BigInteger nameDistinguisher;
   private DERGeneralizedTime dateOfBirth;
   private DirectoryString placeOfBirth;
   private String gender;
   private DirectoryString postalAddress;

   public static PersonalData getInstance(Object obj) {
      if (obj != null && !(obj instanceof PersonalData)) {
         if (obj instanceof ASN1Sequence) {
            return new PersonalData((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (PersonalData)obj;
      }
   }

   private PersonalData(ASN1Sequence seq) {
      if (seq.size() < 1) {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      } else {
         Enumeration seq1;
         this.nameOrPseudonym = NameOrPseudonym.getInstance((seq1 = seq.getObjects()).nextElement());

         while(seq1.hasMoreElements()) {
            ASN1TaggedObject var2;
            switch ((var2 = ASN1TaggedObject.getInstance(seq1.nextElement())).getTagNo()) {
               case 0:
                  this.nameDistinguisher = DERInteger.getInstance(var2, false).getValue();
                  break;
               case 1:
                  this.dateOfBirth = DERGeneralizedTime.getInstance(var2, false);
                  break;
               case 2:
                  this.placeOfBirth = DirectoryString.getInstance(var2, true);
                  break;
               case 3:
                  this.gender = DERPrintableString.getInstance(var2, false).getString();
                  break;
               case 4:
                  this.postalAddress = DirectoryString.getInstance(var2, true);
                  break;
               default:
                  throw new IllegalArgumentException("Bad tag number: " + var2.getTagNo());
            }
         }

      }
   }

   public PersonalData(NameOrPseudonym nameOrPseudonym, BigInteger nameDistinguisher, DERGeneralizedTime dateOfBirth, DirectoryString placeOfBirth, String gender, DirectoryString postalAddress) {
      this.nameOrPseudonym = nameOrPseudonym;
      this.dateOfBirth = dateOfBirth;
      this.gender = gender;
      this.nameDistinguisher = nameDistinguisher;
      this.postalAddress = postalAddress;
      this.placeOfBirth = placeOfBirth;
   }

   public NameOrPseudonym getNameOrPseudonym() {
      return this.nameOrPseudonym;
   }

   public BigInteger getNameDistinguisher() {
      return this.nameDistinguisher;
   }

   public DERGeneralizedTime getDateOfBirth() {
      return this.dateOfBirth;
   }

   public DirectoryString getPlaceOfBirth() {
      return this.placeOfBirth;
   }

   public String getGender() {
      return this.gender;
   }

   public DirectoryString getPostalAddress() {
      return this.postalAddress;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.nameOrPseudonym);
      BigInteger var2;
      DERTaggedObject var3;
      DERTaggedObject var11;
      if ((var2 = this.nameDistinguisher) != null) {
         var11 = var3 = new DERTaggedObject;
         DERInteger var4;
         var4 = new DERInteger.<init>(var2);
         var11.<init>(false, 0, var4);
         var1.add(var3);
      }

      DERGeneralizedTime var6;
      if ((var6 = this.dateOfBirth) != null) {
         var3 = new DERTaggedObject.<init>(false, 1, var6);
         var1.add(var3);
      }

      DirectoryString var7;
      if ((var7 = this.placeOfBirth) != null) {
         var3 = new DERTaggedObject.<init>(true, 2, var7);
         var1.add(var3);
      }

      String var8;
      if ((var8 = this.gender) != null) {
         var11 = var3 = new DERTaggedObject;
         DERPrintableString var10;
         var10 = new DERPrintableString.<init>(var8, true);
         var11.<init>(false, 3, var10);
         var1.add(var3);
      }

      DirectoryString var5;
      if ((var5 = this.postalAddress) != null) {
         DERTaggedObject var9;
         var9 = new DERTaggedObject.<init>(true, 4, var5);
         var1.add(var9);
      }

      return new DERSequence(var1);
   }
}
